==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRowExportingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDetailDescription } from "./WebRowExportingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowExportingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowExportingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowExportingEventArgsDetailDescriptionMetadata.a == null) {
                WebRowExportingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowExportingEventArgsDetailDescriptionMetadata.c(WebRowExportingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebRowExportingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRowExportingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowExportingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("RowData", "Unknown");
            a.item("RowIndex", "Number:double");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebRowExportingEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebRowExportingEventArgsDetail", () => new WebRowExportingEventArgsDetailDescription());
            a.z("WebRowExportingEventArgsDetail", WebRowExportingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowExportingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowExportingEventArgsDetailDescriptionMetadata, 'WebRowExportingEventArgsDetailDescriptionMetadata');
    WebRowExportingEventArgsDetailDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRowExportingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebRowExportingEventArgsDetailDescription } from "./WebRowExportingEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebRowExportingEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRowExportingEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebRowExportingEventArgsDetailDescriptionMetadata.a == null) {
                WebRowExportingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRowExportingEventArgsDetailDescriptionMetadata.c(WebRowExportingEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebRowExportingEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRowExportingEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RowExportingEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("RowData", "Unknown");
            a.item("RowIndex", "Number:double");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebRowExportingEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebRowExportingEventArgsDetail", () => new WebRowExportingEventArgsDetailDescription());
            a.ab("WebRowExportingEventArgsDetail", WebRowExportingEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebRowExportingEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRowExportingEventArgsDetailDescriptionMetadata, 'WebRowExportingEventArgsDetailDescriptionMetadata');
    WebRowExportingEventArgsDetailDescriptionMetadata.a = null;
    return WebRowExportingEventArgsDetailDescriptionMetadata;
})();
